@@ -1,6 +1,6 @@
 use std::io;
 
-use hexyl::{BorderStyle, Printer};
+use hexyl::{BorderStyle, PrinterBuilder};
 
 fn main() {
     let input = vec![
@@ -11,10 +11,14 @@ fn main() {
     let stdout = io::stdout();
     let mut handle = stdout.lock();
 
-    let show_color = true;
-    let use_squeezing = false;
-    let border_style = BorderStyle::Unicode;
-
-    let mut printer = Printer::new(&mut handle, show_color, border_style, use_squeezing);
+    let mut printer = PrinterBuilder::new(&mut handle)
+        .show_color(true)
+        .show_char_panel(true)
+        .show_position_panel(true)
+        .with_border_style(BorderStyle::Unicode)
+        .enable_squeezing(false)
+        .num_panels(2)
+        .group_size(1)
+        .build();
     printer.print_all(&input[..]).unwrap();
 }
